% ****************************************************************** %
%                                                                    %
%                           PMBM.M                                   %
%            Permanent Magnet Motor, Stator in Slots                 %
%             Internal (Flux Concentrating) Magnets                  %
%           Copyright 1995, 1997 James L. Kirtley Jr.                %
%                                                                    %
% ****************************************************************** %
% pmbm.m: main design program
% see 6.11s copyright statement for rules of use
% Requires the following input variables:
% Rotational Speed		rpm
% Required Power		Preq
% Required power factor angle	psi
% Rotor radius			r
% Air-gap			g
% Magnet Radial Extent		hm
% Magnet Azimuthal Extent	wm
% Active Length			l
% Pole Pairs			p
% Slots per pole per phase	m
% Slots short pitched		nsp
% Peripheral Tooth Fraction	lamt
% Slot depth to radius ratio	fsd
% Slot depression depth		hd
% Slot depression width		wd
% Back Iron thickness ratio	fbi
% Turns per coil		nc
% Number of conductors in hand	nh
% Slot Fill Fraction		lama
% Magnet Remanent Flux Density	Br
% Stator Conductivity		siga
% Iron Model: Base Dissipation	P0
% Base Frequency		F0
% Base Flux Density		B0
% Flux Exponent			epb
% Frequency Exponent		epf
% Steel Density			rhos
% Magnet Density		rhom
% Conductor Density		rhoc
% Air temperature rise		dtt
% Assumed fan efficiency	eft
% These are manipulated by:
%  rvars.m contains design parameters
%  svars.m saves these parameters in rvars.m
%  pvars.m prints current variables to the screen

% Here are a few constants
muzero=pi*4e-7;			% free-space permeability
tol=1e-6;			% error tolerance in power loop
cpair = 1005.7;			% mass heat capacity of air
rhoair = 1.1774;		% density of air
nuair = 1.56e-5;		% kinematic viscosity of air

fprintf('PMBM: Buried Magnet Motor Analysis');
% First, generate the rest of the geometry
% Number of stator slots
ns = 6*m*p;
% Number of armature turns
na = 2*m*p*nc;
% tooth width
wt = 2*pi*(r+g+hd)*lamt/ns;
% slot depth
hs = fsd*r;
% slot top width
wst = 2*pi*(r+g+hd)*(1-lamt)/ns;
% slot bottom width
wsb = wst*(r+g+hd+hs)/(r+g+hd);
% core back iron depth
dc = fbi*r/p;
% full-pitched coil throw
nsfp = ns/(2*p);
% actual coil throw
nsct = nsfp - nsp;
% estimate of end cone length
% coil angle
thetae = acos(1-lamt);
% azimuthal travel (half end)
laz = pi*(r+g+hd+.5*hs)*nsct/ns;
% end length (axial)
le1 = laz/tan(thetae);
% end length (half coil)
le2 = laz/sin(thetae);
% rotor angles
% magnet included angle
tht = wm/r;
% pole face angle
thp = pi/p - tht;
% stator inner radius
rs = r+g;

% Electrical frequency
f = p*rpm/60;
om = 2*pi*f;

% Winding factor
gama = 2*pi*p/ns;
kb = sin(m*gama/2)/(m*sin(gama/2));
alfa = pi*nsct/nsfp;
kp = sin(alfa/2);
kw = kb * kp;

% Calculation of magnetic field
% Magnet Permeance Modification Factor
gamam = 1/(1+wm*thp*r/(4*g*hm));
% Fundamental Field
B1 = (4/pi)*sin(p*thp/2)*Br*(wm/(2*g))*gamam;

% Calculation of internal voltage
lambda = 2*r*l*B1*na*kw/p;
% RMS (!) Internal Voltage:
Lambda=lambda/sqrt(2);
Ea = om*Lambda;

% Calculation of reactances: only two count here!
% Air-gap inductance: basic
Lag = (3/2)*(4/pi)*muzero*na^2*kw^2*l*rs/(p^2*g);
% Direct-Axis Air-gap inductance
Lad = Lag*gamam*sin(p*thp/2);
% Quadrature-Axis Air-gap inductance
Laq = Lag*(1-sin(p*tht/2));
% slot leakage
perm = muzero*l*(hd/wd+(1/3)*hs/wst);
Lslot = 2*p*nc^2*perm*(4*m-nsp);
% Synchronous Reactance (Ohms)
Xd = om*(Lad+Lslot);
Xq = om*(Laq+Lslot);

% Misc. Lengths, Volumes and Weights
% Armature Conductor Length
Lac = 2*na*(l+2*le2);
% Armature Conductor Area
Aac = hs*.5*(wst+wsb)*lama/(2*nc);
% Mass of Armature Conductor:
Ma = 3*Lac*Aac*rhoc;
% Overall machine length
Lover = l+2*le1;
% Core Inside Radius
rci = r+g+hd+hs;
% Core Outside Radius
rco = rci + dc;
% Overall Diameter
Dover = 2*rco;
% Core Mass
Mcb = rhos*l*pi*(rco^2-rci^2);			% Back Iron
Mct = rhos*l*(ns*wt*hs+2*pi*r*hd-ns*hd*wd);	% Teeth
Mc = Mcb + Mct;
% Magnet Mass
Mm = 2*p*l*hm*wm*rhom;
% Pole Piece Mass
Mp = rhos*l*(pi*(r^2-(r-hm)^2)-2*p*hm*wm);
% stator resistance
Ra = Lac/(siga*Aac);

% Tooth Flux Density (RMS)
Bt = B1/(sqrt(2)*lamt);
% Back Iron Flux Density (RMS)
Bb = B1*r/(sqrt(2)*p*dc);
% Core Iron Loss
Pcb = Mcb*P0*abs(Bb/B0)^epb*abs(f/F0)^epf;
% Teeth
Pct = Mct*P0*abs(Bt/B0)^epb*abs(f/F0)^epf;
Pc = Pcb+Pct;

% Ok: now we go into a loop to see if we can actually get
% terminal voltage and current
% This will probably crash here if the rating is impossible
notdone = 1;
Va = Ea;
Ia = Preq/(3*Va*cos(psi));
while notdone == 1,
 delt = -atan(Xq*Ia*cos(psi)/(Va+Xq*Ia*sin(psi)));
 Iq = Ia*cos(psi-delt);
 Id = - Ia*sin(psi-delt);
 E1 = sqrt((Va+Xq*Ia*sin(psi))^2+(Xq*Ia*cos(psi))^2);
 Eas = E1 - (Xd-Xq)*Id;
 fprintf('.');
% Now estimate losses
 Pa = 3*Ia^2*Ra;

% Estimate of gap friction loss
% Reynold's Number in the gap
  omegam = om/p;
  ren = omegam*r*g/nuair;
% that gives a friction factor
  ff = .0076/ren^.25;
% and that in turn leads to windage loss
  pwind = 2*pi*r^4*omegam^3*l*rhoair*ff;

% fan pressure rise estimated from rotor peripheral speed
  deltap = .5* rhoair * (omegam * r)^2;
% mass flow based on temperature rise
  mdot = (Pc + Pa + pwind)/(cpair * dtt);
% then fan power is volume flow times pressure drop
  pfan = mdot * deltap / (rhoair * etf);

% Ptemp is provisional rating: check to see if it is right
 Ptemp = 3*Va*Ia*cos(psi)-pfan-pwind;

 eratio = Ea/Eas;
 pratio = Preq/Ptemp;
 if abs(eratio - 1) + abs(pratio -1) < tol,  % if true we are done
  notdone = 0;
 else					     % otherwise adjust
  Va = Va * eratio;
  Ia = Ia * pratio/eratio;
 end
end				% end of power adjustment loop

% Performance Characterization
% Slot Current Density
Ja = 2*nc*Ia/(hs*.5*(wst+wsb));
% tip (rotor peripheral) speed
stip = r*om/p;
Pin = Preq+Pc+Pa+pwind+pfan;
eff = Preq/Pin;
pfact = cos(psi);
xd = Xd*Ia/Ea;
xq = Xq*Ia/Ea;

% Estimate of de-magnetizing MMF
% Current with a slipped pole:
Isp = (Va+Ea)/Xd;
% Fundamental MMF from that:
Fsp = Isp*na*kw/p;
% Magnet part of that
Fspm = Fsp/(1+4*hm*g/(r*thp*wm));
% Demagnetizing Field (in A/m)
Hdm = Fspm/wm;
fprintf('\n pmbm Ea = %g  Ia = %g  ',Ea,Ia);
fprintf('Va = %g  Hdm = %g\n',Va,Hdm);
fprintf('Internal Flux Based xd = %g  xq = %g\n',xd, xq);
fprintf('PMBM done: ready\n');
