% ****************************************************************** %
%                                                                    %
%                           PMBM.M                                   %
%            Permanent Magnet Motor, Stator in Slots                 %
%             Internal (Flux Concentrating) Magnets                  %
%         Copyright 1995, 1997 James L. Kirtley Jr.                  %
%                                                                    %
% ****************************************************************** %
% pmperf.m: Performance Limits vs. speed
% see 6.11s copyright statement for rules of use
% Must run pmbm.m first!
% per-unit reactances
xd=Xd*Ia/Ea;
xq=Xq*Ia/Ea;
omratio = input('Ratio of max speed to base speed? ==> ');
% base torque level
% lambda is peak internal flux and Ia is RMS current
TBE = p*3*lambda*Ia/sqrt(2);
% Part 1: trajectory of optimal current placement
ia = .05:.05:1;
% note that the round-rotor case must be handled separately
if xd==xq,
  id = zeros(size(ia));
  iq = ia;
else
  c1 = .5 .* ia .^2;
  c2 = (1/(4*(xq-xd)))^2;
  id = -sqrt(c1 + 2*c2 - (.5/(xq-xd)).* sqrt(c2 + c1));
  iq = sqrt(c1 - 2*c2 + (.5/(xq-xd)).* sqrt(c2 + c1));
end
th = 0:pi/50:pi;
% id0 and iq0 are the direct and quad axis currents at the rating point
% Psi is the per-unit terminal flux at that rated point
id0 = id(length(ia));
iq0 = iq(length(ia));
Psi = sqrt((1+xd*id0)^2+(xq*iq0)^2);
% Now we can compute a "base speed", which is related to terminal
% voltage and this terminal flux
omB = Va/(Lambda*Psi);
% Base RPM is:
rpmbase = (60/(2*p*pi))*omB;
fprintf('Base Speed (Rated Voltage) = %g RPM\n',rpmbase);
% the ratio of maximum to base speed is omratio
rpmm = omratio*rpmbase;
% there are two cases, depending on the value of xd
if xd<1,
% first, we must generate a minimum value for iq
% we go to zero torque speed if xd<1 and the called for speed ratio is high
% this case is easy, and iq is used as a parameter
  if omratio > Psi/(1-xd),        
    iqm = 0;
% now generate a vector of iq
    diq = (iq0-iqm)/50;
    iqs = iq0:-diq:iqm;
% current is always on the current capability frontier
    ids = -sqrt(1 - iqs .^2);
    te = (1 - (xq - xd) .* ids) .* iqs;
% psis is the flux produced by this pair of currents 
    psis = sqrt((1 + xd .* ids) .^2 + (xq .* iqs) .^2);
% and flux determines the speed
    omr = Psi ./ psis;
  else
% or we go to specified maximum speed
% here we use flux as the parameter
    psir = Psi/omratio;
    dpsi = (Psi-psir)/50;
    psis = Psi:-dpsi:psir;
    omr = Psi ./ psis;
% we need to handle the non-salient case separately
    if xd==xq,
      ids = (psis .^2 - 1 - xd^2)./(2 * xd);
    else    
      a = xd/(xq^2-xd^2);
      b = (xq^2-psis.^2+1)/(xq^2-xd^2);
      ids = a - sqrt(a^2+b);
    end
    iqs = sqrt(1-ids.^2);
    te = (1 - (xq - xd) .* ids) .* iqs;
  end
% now we generate the case of xd>1
% Note: this is harder! But we can always make it to speed
else
% we use flux as the parameter here
  psir = Psi/omratio;
  dpsi = (Psi-psir)/50;
  psis = Psi:-dpsi:psir;
% but the complexity requires us to un-vectorize the calculation
  ids = zeros(size(psis));
  iqs = zeros(size(psis));
  for i=1:length(psis);
% here are the voltage limited currents that give maximum torque
    if xd==xq;
      idt = -1/xd;
      iqt = psis(i)/xq;
    else
      a = (3*xd*(xq-xd)-xd^2)/(2*xd^2*(xq-xd));
      b = ((xq-xd)*(psis(i) ^2 - 1) + xd)/(2*xd^2*(xq-xd));
      idt = -.5*a - sqrt((.5*a)^2 + b);
      iqt = (1/xq) * sqrt(psis(i)^2 - (1 + xd * idt) ^2);
    end
% but these may be outside the current capability curve
% if so, we must compute the intersection of voltage and current curves
    if sqrt(idt^2+iqt^2)>1,
      if xd==xq,
        ids(i)=(psis(i)^2-1-xd^2)/(2*xd);
      else
        a = xd/(xq^2-xd^2);
        b = (xq^2-psis(i)^2+1)/(xq^2-xd^2);
        ids(i) = a - sqrt(a^2+b);
      end
      iqs(i) = sqrt(1-ids(i)^2);
    else
      ids(i) = idt;
      iqs(i) = iqt;
    end
  end
  te = (1 - (xq - xd) .* ids) .* iqs;
  omr = Psi ./ psis;
end
% Plot of torque-speed and power-speed curves
figure(1)
clf
Speed = omr .* rpmbase;
Torque = te .* TBE;
Speedp = [0 Speed];
Torquep = [Torque(1) Torque];
subplot(211)
SM = Speed(length(Speed));
TM = 1.1*Torque(1);
axis([0 SM 0 TM])
plot(Speedp, Torquep);
title('PM Brushless Machine');
ylabel('Torque, N-m');
Om = omB .* omr;
Power = Torque .* Om;
Powerp = [0 Power];
subplot(212)
PM = 1.1*max(Powerp);
axis([0 SM 0 PM])
plot(Speedp, Powerp);
xlabel('Speed, RPM');
ylabel('Power, Watts');
