% ****************************************************************** %
%                                                                    %
%                           PMRS.M                                   %
%            Permanent Magnet Motor, Stator in Slots                 %
%                      Surface Magnets                               %
%          Copyright 1995, 1997 James L. Kirtley Jr.                 %
%                                                                    %
% ****************************************************************** %
% pmrs.m: main design program
% see 6.11s copyright statement for rules of use
% Requires the following input variables:
% Rotational Speed		rpm
% Required Power		Preq
% Required power factor angle	psi
% Rotor radius			r
% Air-gap			g
% Magnet Thickness		hm
% Active Length			l
% Pole Pairs			p
% Slots per pole per phase	m
% Slots short pitched		nsp
% Peripheral Tooth Fraction	lamt
% Slot depth to radius ratio	fsd
% Slot depression depth		hd
% Slot depression width		wd
% Back Iron thickness ratio	fbi
% Turns per coil		nc
% Number of conductors in hand	nh
% Slot Fill Fraction		lama
% Magnet Remanent Flux Density	Br
% Magnet Electrical Angle	thme
% Stator Conductivity		siga
% Iron Model: Base Dissipation	P0
% Base Frequency		F0
% Base Flux Density		B0
% Flux Exponent			epb
% Frequency Exponent		epf
% Steel Density			rhos
% Magnet Density		rhom
% Conductor Density		rhoc
% Air temperature rise		dtt
% Assumed fan efficiency	eft

% Here are a few constants
muzero=pi*4e-7;			% free-space permeability
tol=1e-6;			% error tolerance in power loop
cpair = 1005.7;			% mass heat capacity of air
rhoair = 1.1774;		% density of air
nuair = 1.56e-5;		% kinematic viscosity of air

fprintf('PMRS Surface Magnet Motor Analysis');
% First, generate the rest of the geometry
% Number of stator slots
ns = 6*m*p;
% Number of armature turns
na = 2*m*p*nc;
% tooth width
wt = 2*pi*(r+g+hd)*lamt/ns;
% slot depth
hs = fsd*r;
% slot top width
wst = 2*pi*(r+g+hd)*(1-lamt)/ns;
% slot bottom width
wsb = wst*(r+g+hd+hs)/(r+g+hd);
% core back iron depth
dc = fbi*r/p;
% full-pitched coil throw
nsfp = ns/(2*p);
% actual coil throw
nsct = nsfp - nsp;
% estimate of end cone length
% coil angle
thetae = acos(1-lamt);
% azimuthal travel (half end)
laz = pi*(r+g+hd+.5*hs)*nsct/ns;
% end length (axial)
le1 = laz/tan(thetae);
% end length (half coil)
le2 = laz/sin(thetae);

% Electrical frequency
f = p*rpm/60;
om = 2*pi*f;
% surface speed
stip = r*om/p;

% Winding factor
gama = 2*pi*p/ns;                     % electrical angle of slot pitch
kb = sin(m*gama/2)/(m*sin(gama/2));   % breadth factor
alfa = pi*nsct/nsfp;                  % electrical angle of each coil
kp = sin(alfa/2);                     % pitch factor
kw = kb * kp;                         % So here is total winding factor

% Calculation of magnetic field
rmi=r-hm;                             % radius of magnet bottom
rs=r+g;                               % radius of outside of air-gap
if p==1,                              % two pole machine is special
 kg = (.5*(r^2-rmi^2)+rmi^2*log(r/rmi))/(rs^2-rmi^2);          % gap factor (fund of B/Br)
else
 kg = (rs^(p-1)/(rs^(2*p)-rmi^(2*p)))*...                      % solution of Laplace' equation
      ( (p/(p+1))*(r^(p+1)-rmi^(p+1))+...
        (p/(p-1))*(rmi^(2*p)) * (rmi^(1-p)-r^(1-p)) );
end
B1 = (4/pi)*sin(thme/2)*Br*kg;                                 % peak value of fundamental field

% Calculation of internal voltage
lambda = 2*rs*l*B1*na*kw/p;                                    % total (peak) flux density
% RMS (!) Internal Voltage:
Ea = om*lambda/sqrt(2);             

% Calculation of reactances: only two count here!
% Air-gap inductance:
Lag = (3/2)*(4/pi)*muzero*na^2*kw^2*l*rs/(p^2*(g+hm));         % air-gap inductance
% slot leakage
perm = muzero*l*(hd/wd+(1/3)*hs/wst);                          % slot permeance
Lslot = 2*p*nc^2*perm*(4*m-nsp);                               % this is slot leakage inductance
% Synchronous Reactance (Ohms)
Xs = om*(Lag+Lslot);


% Misc. Lengths, Volumes and Weights
% Armature Conductor Length
Lac = 2*na*(l+2*le2);
% Armature Conductor Area
Aac = hs*.5*(wst+wsb)*lama/(2*nc);
% Mass of Armature Conductor:
Ma = 3*Lac*Aac*rhoc;
% Overall machine length
Lover = l+2*le1;
% Core Inside Radius
rci = r+g+hd+hs;
% Core Outside Radius
rco = rci + dc;
% Overall Diameter
Dover = 2*rco;
% Core Mass
Mcb = rhos*l*pi*(rco^2-rci^2);			% Back Iron
Mct = rhos*l*(ns*wt*hs+2*pi*r*hd-ns*hd*wd);	% Teeth
Mc = Mcb + Mct;
% Magnet Mass
Mm = 0.5*thme*(r^2-(r-hm)^2)*l*rhom;
% Shaft Mass
Ms = pi*(r-hm)^2*l*rhos; 
% stator resistance
Ra = Lac/(siga*Aac);

% Tooth Flux Density (RMS)
Bt = B1/(sqrt(2)*lamt);
% Back Iron Flux Density (RMS)
Bb = B1*r/(sqrt(2)*p*dc);
% Core Iron Loss
Pcb = Mcb*P0*abs(Bb/B0)^epb*abs(f/F0)^epf;
% Teeth
Pct = Mct*P0*abs(Bt/B0)^epb*abs(f/F0)^epf;
Pc = Pcb+Pct;

% Ok: now we go into a loop to see if we can actually get
% terminal voltage and current
% This will probably crash here if the rating is impossible
notdone = 1;
Ia = Preq/(3*Ea);
while notdone == 1,
 xa = Xs*Ia/Ea;
 vr = sqrt(1-xa^2*cos(psi)^2)-xa*sin(psi);

% Calculation of Losses

Pa = 3*Ia^2*Ra;            % armature ohmic losses

% Estimate of gap friction loss
% Reynold's Number in the gap
  omegam = om/p;
  ren = omegam*r*g/nuair;
% that gives a friction factor
  ff = .0076/ren^.25;
% and that in turn leads to windage loss
  pwind = 2*pi*r^4*omegam^3*l*rhoair*ff;

% fan pressure rise estimated from rotor peripheral speed
  deltap = .5* rhoair * (omegam * r)^2;
% mass flow based on temperature rise
  mdot = (Pc + Pa + pwind)/(cpair * dtt);
% then fan power is volume flow times pressure drop
  pfan = mdot * deltap / (rhoair * etf);
 
 Va = Ea*vr;                                           % volt-amperes
 Ptemp = 3*Va*Ia*cos(psi)-pfan-pwind;                  % provisional output power

 eratio = Preq/Ptemp;                                  % how close are we to required power?
 if abs(eratio - 1) < tol,                             % done!
  notdone = 0;
 else
  Ia = Ia * eratio;                                    % try adjusting current to get closer
 end
 fprintf('.');                                         %  stayin' alive
end

% Performance Characterization

% Slot Current Density
Ja = 2*nc*Ia/(hs*.5*(wst+wsb));         

Pin = Preq+Pc+Pa+pwind+pfan;                           % input power for that output point
eff = Preq/Pin;                                        % indicated efficiency
pfact = cos(psi);                                      % power factor (but we knew that already!)

fprintf('PMRS done: ready\n');
