
% ************************************************************** %
%                                                                %
%                 Polyphase Motor Design Program                 %
%                            MOTOR                               %
%                     Single Squirrel Cage                       %
%       Parallel Rotor Body Conductivity (nonlinear model)       %
%             Copyright 1994, 1995, 1997                         %
%                       J.L. Kirtley Jr.                         %
%                                                                %
% ************************************************************** %
% See 6.11s Copyright Statement for Rules of Use
% Here are required input variables:
% Machine rating		Prat
% Terminal Voltage		volt
% electrical frequency		f
% Rotor radius			r
% Active length			l
% physical air-gap		g
% number of pole pairs		p
% Armature turns/pole/phase     nc
% slots per pole per phase 	ma
% number of rotor slots		nr
% stator slot depression depth	ds
% stator slot depression width	us
% stator slot height 		hs
% stator slot (top) fraction	lams
% stator winding short pitch	nst
% rotor slot depression depth	dr
% rotor slot depression width	ur
% rotor slot width		wr
% rotor slot depth		hr
% rotor end ring height		he
% rotor end ring length 	le
% rotor skew			sk
% rotor conductor conductivity	sigr
% stator conductor conductivity	siga
% rotor body conductivity	sirb
% stator conductor space factor lama
% core iron depth		db
% core iron base dissipation	pb
% core iron base frequency	omb
% core iron diss flux expon	epps
% core iron diss freq expon	epf
% core iron var base 1		vaa1
% core iron var base 2		vaa2
% core iron var expon 1		epa1
% core iron var expon 2		epa2
% rotor conductor mass density	rhor
% cooling air temperature rise	dtt
% cooling fan efficiency	etf
% cooling fan radius		rfan

% A few constants of nature and other assumed constants
mu = 1.2566e-6;
rhofe = 7400;	     % assumed core iron density %
rhos = 8400;         % assumed stator conductor density (copper)
B0 = 1.5;            % flux density to use in nonlinear iron calc
bb = 1;		     % base flux density for loss calculations %
cpair = 1005.7;      % mass heat capacity of air
rhoair = 1.1774;     % density of air
nuair = 1.56e-5;     % kinematic viscosity of air

fprintf ('MOTOR: Induction Motor Analysis\n');
% total stator slots
ns = ma * (6 * p);
% stator slot pitch (in radians)
% gama = 2 * pi * p / ns;
% coil throw in slots
 nct = 3*ma - nst;
% coil throw (in electrical radians)
% alfa = p * pi * nct / ns;
% electrical frequency
omega = 2 * pi * f;
% armature turns
na = 2*nc*ma*p; 
% calculation of slot width: top and bottom
lamt = 1.0 - lams;
wt = lamt * 2*pi*(r+ds)/ns;
ws = 2*pi*(r+ds)/ns - wt; 	
wsb = 2*pi*(r+ds+hs)/ns - wt; 	

% stator winding factors
ka = windf(1,p,ma,nst);
ka5 = windf(5,p,ma,nst);
ka7 = windf(7,p,ma,nst);

% if ma>1 we need to compute a separate zigzag component
% np and nm are the positive and negative zigzag harmonic orders
if ma>1,
  np = ns/p+1;
  nm = ns/p-1; 
  kap = windf(np,p,ma,nst);
  kam = windf(nm,p,ma,nst);
else
  np = ns+1;
  nm = ns-1;
  kap = windf(np, 1, ma, nst);
  kam = windf(nm, 1, ma, nst);
end

% Extension of the air-gap because of slot openings
% slot top is depression width
sts = us;
str = ur;
% tooth width is the rest:
tws = 2*pi*r/ns - sts;
twr = 2*pi*r/ns - str;
% now two coefficients: slot top to slot pitch
a_s = sts/(sts+tws);
a_r = str/(str+twr);
% and slot top to gap
b_s = sts/g;
b_r = str/g;
alphas = atan(sts/(2*g));
alphar = atan(str/(2*g));
% the famous Carter Coefficient is, from Lipo:

ccs = 1/(1-(2/pi)*a_s*(atan(b_s/2)-(1/b_s)*log(1+(b_s/2)^2)));
ccr = 1/(1-(2/pi)*a_r*(atan(b_r/2)-(1/b_r)*log(1+(b_r/2)^2)));

geff = g*ccs*ccr;
fprintf('original gap = %g  corrected gap = %g\n',g,geff);

% Air- gap inductance components
% Space Fundamental Component: Magnetizing Reactance
xag1 = (6.0/pi) * omega * mu * na^2 * ka^2 * r * l/(p^2 * geff);

% Stator Leakage Inductance Calculation
% Harmonic Components: Belt Leakage Reactance
xa5 = xag1 * (ka5 / (ka * 5))^2;
xa7 = xag1 * (ka7 / (ka * 7))^2;

% Harmonic Components: Stator Zigzag Reactance
if ma>1,
  xap = xag1 * (kap / (ka * np))^2;
  xam = xag1 * (kam / (ka * nm))^2;
end

% Stator Slot Leakage
% slot permeance
pss = mu * l * (ds/us + (1/3) * hs/ws);
% slot leakage reactance
xsa = 18.0 * omega * pss * na^2 * (ns/6 + p * nct)/ns^2;

% Skew Leakage Reactance
xka = xag1 * (1.0 - (2.0/sk) * sin (0.5 * sk));
xk5 = xag1 * (1.0 - (2.0/(5.0*sk)) * sin (2.5 * sk));
xk7 = xag1 * (1.0 - (2.0/(7.0*sk)) * sin (3.5 * sk));

if ma>1,
  xkp = xag1 * (1.0 - (2.0/(np*sk)) * sin (0.5*np*sk));
  xkm = xag1 * (1.0 - (2.0/(nm*sk)) * sin (0.5*nm*sk));
end

% Rotor Zigzag Harmonics
% Stator Fundamental Part: part of rotor leakage
xrza = xag1 * p^2 * (1.0/(nr+p)^2 + 1.0/(nr-p)^2);	

% Harmonic Components: Shunting Stator Belt Leakage
xrz5a = xa5 * p*p * (1.0/(nr+5*p)^2 + 1.0/(nr-5*p)^2);	
xrz7a = xa7 * p*p * (1.0/(nr+7*p)^2 + 1.0/(nr-7*p)^2);	

if ma>1,
xrzpa = xap * p*p * (1.0/(nr+np*p)^2 + 1.0/(nr-np*p)^2);	
xrzma = xam * p*p * (1.0/(nr+nm*p)^2 + 1.0/(nr-nm*p)^2);	
end

% Trivial model for stator winding end leakage (From Alger)
xe = (14/(4 * pi^2))*(3/2) * mu * r * na^2 * (p - 0.3)/p^2;

% Stator Resistance
% effective length of wire per phase
lea = 2 * (l + pi * (r+ds+.5*hs) / p) * na;

% slot area
aslot = 0.5*hs*(ws+wsb);

% wire area
area = (lama/6.0) * aslot * ns/na;

% total resistance per phase
r1a = lea /(siga*area);

% rotor conductor mass (including end ring)
massr = nr*wr*hr*l*rhor + pi*((r-g-dr)^2-(r-g-dr-he)^2)*le*rhor;
		
% total stator conductor mass
massa = lea * area * rhos;
	
% now find core resistance elements
% rotor tooth peripheral space factor
lamtr = 1 - nr * wr / (2 * pi * (r - g - dr - 0.5 * hr));

% Air-gap flux density:
bg = p * volt/(2 * r * l * omega * ka * na);

% stator tooth flux density
bt = bg / lamt;

% tooth loss density, watts per kilogram 
% pit = pb * abs(bt/bb)^epps * abs(omega/omb)^epf;
pit = fepwr(bt, omega, pb, bb, omb, epps, epf);

% tooth Var density, VA per kilogram 
% vat = vaa1 * (abs(bt/bb)^epa1 + vaa2 * abs(bt/bb)^epa2)*(omega/omb);
vat = fevar (bt, omega, bb, vaa1, epa1, vaa2, epa2, omb);

% back iron flux density
bc = bg * r / (p * db);

% back iron loss density
% pic = pb * abs(bc/bb)^epps * abs(omega/omb)^epf;
pic = fepwr(bc, omega, pb, bb, omb, epps, epf);

%back iron VAR density, VA per kilogram
% vab = vaa1 * (abs(bt/bb)^epa1 + vaa2 * abs(bt/bb)^epa2)*(omega/omb);
vab = fevar (bc, omega, bb, vaa1, epa1, vaa2, epa2, omb);

% rotor tooth flux density
brt = bg/lamtr;
% rotor var density (only teeth!), 
% vart = vaa1 * (abs(brt/bb)^epa1 + vaa2 * abs(brt/bb)^epa2)*(omega/omb);
vart = fevar (brt, omega, bb, vaa1, epa1, vaa2, epa2, omb);

% mass of teeth
mtoothr = pi * ((r-g-dr)^2-(r-g-dr-hr)^2)*l*rhofe*lamtr;
mtooth = 2 * pi * r * (hs+ds) * l * rhofe * lamt;

% mass of back iron
mcore = pi * ((r+ds+hs+db)^2-(r+ds+hs)^2)*l*rhofe;
mcorer = pi * ((r-g-dr-hr+db)^2-(r-g-dr-hr-db)^2)*l*rhofe;
	
% total iron mass
miron = mtooth + mtoothr + mcore + mcorer;
% total active mass
mtot = miron + massa + massr;

% total loss at nominal flux density
pc = pit*mtooth + pic * mcore;
% and VA
vac = vat*mtooth + vab*mcore + vart*mtoothr;

% then core parallel resistance is %
rc = 3 * volt^2 / pc;
% and parallel reactance is:
xc = 3 * volt^2 / vac;

% parallel resistance element for zigzag flux loss
% first, generate nominal zigzag flux variation:
% thetad is the normalized angular slot opening
thetad = ns*us/r;

% bzz is the nominal flux variation
bzz = bg * (2/pi) * sin (0.5*thetad);

% first, loss estimated for the laminated rotor
% msurf is the mass of iron affected by zigzag flux
% dsurf is the depth of iron affected
dsurf = r/ns;
msurf = pi * ((r-g)^2-(r-g-dsurf)^2)*l*rhofe*lamtr;

% and psurf is the nominal power:
% psurf = pb * abs(bzz/bb)^epps * abs(ns*omega/omb)^epf * msurf;
psurf = msurf * fepwr(bzz, ns*omega, pb, bb, omb, epps, epf);

% so then the equivalent resistance is:
rsurf = 3 * volt^2 / psurf;

% now do the same estimate for a solid rotor
if sirb > 0,
	% ezz is axial electric field from flux variation
  ezz = bzz*r*omega/p;
  deltrs = hr;
  notdoners = 1;
	% iterate until surface current and skin depth are consistent
  while notdoners == 1,
	% rrsurf is the real part of surface resistance: reactive part
	% is half of that, so total magnitude is 1.118 times rrsurf
    rrsurf = (8/(3*pi))*(1/(sirb*deltrs));
    krsurf = ezz/(1.118*rrsurf);
	% new guess for skin depth
    deltrsgnu = sqrt(2*B0/(sirb*ns*omega*krsurf));
    errdelt = 1-deltrs/deltrsgnu;
    if abs(errdelt) < .0001, notdoners = 0; end
    deltrs = deltrsgnu;
  end		% end of surface impedance loop

% now we can do a first cut for dissipation in this:
prsurf = 2*pi*r*l*krsurf^2/(sirb*deltrs);
% and rsurfrs is the equivalent (terminal) resistance
rsurfrs = 3*volt^2/prsurf;
end		% end of if sirb>0

% to get things started we need to compute a few initial guesses
% here is an initial value for slip: it is modified at the bottom
% of the loop
s = .001;

% and an initial guess as to the nonlinear rotor surface resistance
% starting value of current used for a nonlinear resistance estimator
i2a = Prat/(3*volt);
i2s = 0.5*i2a;
vf = volt;

if sirb > 0,
  % iteration here is based on impedance
  notbal=1;
  while notbal==1,
    % kza is rotor surface current, based on |i2|
    kza = (3/pi) * na * ka * i2s / r;

    % delta is penetration depth based on nonlinear theory
    delta = sqrt(2*kza/(sirb * s * omega* B0));

    % rca and xca are resistive and reactive components of surface
    % impedance
    rca = (8/(3*pi))*(1/(sirb*delta));
    xca = 0.5 * rca;

    % now equivalent impedance, referred to the stator is:
    r2rs = (3/2)*(4/pi)*(l/r)*na^2*ka^2*rca;
    x2rs = (3/2)*(4/pi)*(l/r)*na^2*ka^2*xca;

    % and the presented impedance of this is
    zs = j*x2rs + r2rs/s;
    i2n = abs(volt/zs);
    if abs(i2n/i2s-1)<1e-4, notbal=0; end
    i2s = i2n;
  end

% Rotor Slot Impedance: Diffusion Model
  oms = s * omega;			    % slip frequency 
  delr = sqrt (2.0 / (sigr * oms * mu));    % skin depth
  arg = 2 * hr / delr;			    % arg of trig funcs
	% lslot and rslot are slot inductance and resistance
  lslot = mu*dr/ur + ...
     (1/oms)*(1/(sigr*delr*wr))*tffl(arg);
  rslot = (1/(sigr*delr*wr))*tffr(arg);
	% xra is slot reactance referred to the stator winding
  xra = omega * 12 * l * na^2 * ka^2 * lslot / nr;
	% r2s and r2e are straight and end ring parts of resistance
  r2s = 12 * l * na^2 * ka^2 * rslot / nr;	
  r2e = r2s * (nr * r * wr * hr)/(pi * l * le * he * p^2);
  r2a = r2s + r2e;			% total resistance, ref to stator
  x2a = xra + xka + xrza;		% reactance, slot+skew+zigzag
  z2c = j*x2a+r2a/s;			% cage impedance
  z2s = j*xca+rca/s;			% rotor body impedance
  i2c = i2a*z2s/(z2c+z2s);		% current divider: cage current
end

% slip loop: adjust slip until power is right
notdone=1;
while notdone==1
  omegam = omega * (1-s) / p;		% rotor electrical speed

% Rotor Slot Impedance
  oms = s * omega;			    % slip frequency 
  delr = sqrt (2.0 / (sigr * oms * mu));    % skin depth
  arg = 2 * hr / delr;			    % arg of trig func's

% harmonic slips
  s5 = 5*(1-s)+1;
  s7 = -7*(1-s)+1;
  sm = nm*(1-s)+1;
  sp = -np*(1-s)+1;

% and corresponding harmonic frequencies
  om5 = abs(s5)*omega;
  om7 = abs(s7)*omega;
  omm = abs(sm)*omega;
  omp = abs(sp)*omega;

% skin depths (in cage conductors)
  delr5 = sqrt(2.0 / (sigr * om5 * mu));
  delr7 = sqrt(2.0 / (sigr * om7 * mu));
  delrm = sqrt(2.0 / (sigr * omm * mu));
  delrp = sqrt(2.0 / (sigr * omp * mu));

% corresponding arguments
  arg5 = 2 * hr / delr5;
  arg7 = 2 * hr / delr7;
  argm = 2 * hr / delrm;
  argp = 2 * hr / delrp;
	
% Slot Inductance, per unit length
  lslot = mu*dr/ur + ...
     (1/oms)*(1/(sigr*delr*wr))*tffl(arg);
  lslot5 = mu*dr/ur + ...
     (1/oms)*(1/(sigr*delr5*wr))*tffl(arg5);
  lslot7 = mu*dr/ur + ...
     (1/oms)*(1/(sigr*delr7*wr))*tffl(arg7);
  lslotm = mu*dr/ur + ...
     (1/oms)*(1/(sigr*delrm*wr))*tffl(argm);
  lslotp = mu*dr/ur + ...
     (1/oms)*(1/(sigr*delrp*wr))*tffl(argp);

% Slot Resistance, per unit length
  rslot = (1/(sigr*delr*wr))*tffr(arg);
  rslot5 = (1/(sigr*delr5*wr))*tffr(arg5);
  rslot7 = (1/(sigr*delr7*wr))*tffr(arg7);
  rslotm = (1/(sigr*delrm*wr))*tffr(argm);
  rslotp = (1/(sigr*delrp*wr))*tffr(argp);

% Rotor Reactance, referred to stator
% Fundamental Component: part of rotor leakage
  xra = omega * 12 * l * na^2 * ka^2 * lslot / nr;

% Harmonic Components: Shunting Stator Leakage
  xr5a = omega * 12 * l * na^2 * ka5^2 * lslot5 / nr;
  xr7a = omega * 12 * l * na^2 * ka7^2 * lslot7 / nr;

  if ma>1,
    xrpa = omega * 12 * l * na^2 * kap^2 * lslotp / nr;
    xrma = omega * 12 * l * na^2 * kam^2 * lslotm / nr;
  end

% Rotor Resistance
% straight section
r2s = 12 * l * na^2 * ka^2 * rslot / nr;	
% end resistance
r2e = r2s * (nr * r * wr * hr)/(pi * l * le * he * p^2);
% total
r2a = r2s + r2e;

% harmonic components:
r2s5 = 12 * l * na^2 * ka5^2 * rslot5 / nr;	
r2e5 = r2s5 * (nr * r * wr * hr)/(pi * l * le * he * 25 * p^2);
r2a5 = r2s5 + r2e5;

r2s7 = 12 * l * na^2 * ka7^2 * rslot7 / nr;	
r2e7 = r2s7 * (nr * r * wr * hr)/(pi * l * le * he * 49 * p^2);
r2a7 = r2s7 + r2e7;

if ma>1,
  r2sm = 12 * l * na^2 * kam^2 * rslotm / nr;	
  r2em = r2sm * (nr * r * wr * hr)/(pi * l * le * he * nm^2 * p^2);
  r2am = r2sm + r2em;

  r2sp = 12 * l * na^2 * kap^2 * rslotp / nr;	
  r2ep = r2sp * (nr * r * wr * hr)/(pi * l * le * he * np^2 * p^2);
  r2ap = r2sp + r2ep;
end

% Provision for rotor surface: if the rotor is solid
if sirb > 0,
  % iteration here is based on impedance
  notbal=1;
  while notbal==1,
  % kza is rotor surface current, based on |i2|
  i2sa = abs(i2s);
  kza = (3/pi) * na * ka * i2sa / r;

  % delta is penetration depth based on nonlinear theory
  deltap = sqrt(2*kza/(sirb * s * omega* B0));
  if deltap < r/(2*p), 
     delta=deltap; 
  else delta = r/(2*p); 
  end
  % this is an arbitrary limit: need to do this better!

  % rca and xca are resistive and reactive components of surface
  % impedance
  rca = (8/(3*pi))*(1/(sirb*delta));
  xca = 0.5 * rca;

  % now equivalent impedance, referred to the stator is:
  r2rs = (3/2)*(4/pi)*(l/r)*na^2*ka^2*rca;
  x2rs = (3/2)*(4/pi)*(l/r)*na^2*ka^2*xca;

  % and the presented impedance of this is
  zs = j*x2rs + r2rs/s;
  i2n = abs(volt/zs);
  if abs(i2n/i2s-1)<1e-4, notbal=0; end
  i2s = i2n;
end

  % next step is to estimate the same elements for higher
  % order harmonic terms. Here we use a linear model for
  % the rotor based on the same incremental permeability
  % computed for the fundamental
  if B0/kza > mu, muharm = B0/kza; else muharm=mu; end

  % corresponding skin depths
  delt5 = sqrt(2/(om5*muharm*sirb));
  delt7 = sqrt(2/(om7*muharm*sirb));

  % and resistance: note reactance is the same
  r2rs5 = (3/2)*(4/pi)*(l/r)*na^2*ka^2/(sirb*delt5);
  r2rs7 = (3/2)*(4/pi)*(l/r)*na^2*ka^2/(sirb*delt7);
  x2rs5 = r2rs5;
  x2rs7 = r2rs7;

  if ma>1,
    deltm = sqrt(2/(omm*muharm*sirb));
    deltp = sqrt(2/(omp*muharm*sirb));
    r2rsm = (3/2)*(4/pi)*(l/r)*na^2*ka^2/(sirb*deltm);
    r2rsp = (3/2)*(4/pi)*(l/r)*na^2*ka^2/(sirb*deltp);
    x2rsm = r2rsm;
    x2rsp = r2rsp;
  end
% end of special parameters for rotor surface conductances
end

% Now we can assemble the major inductances
% Remember that xag is computed above
% There are four major impedance blocks, six if ma>1

% Stator Leakage Reactance
% This consists of slot and end leakage
x1a = xsa + xe;

% Stator Section Impedance
z1 = j*x1a + r1a;

% Space Fundamental Section

% Rotor Leakage Reactance
% This consists of slot, skew and zigzag terms 
x2a = xra + xka + xrza;
 
% core elements: air-gap and core reactance in shunt
xg = xag1*xc/(xag1+xc);

% magnetizing element shunted by core resistance:
zag = j*xg*rc/(j*xg+rc);
% cage part of rotor:
z2c = j*x2a + r2a/s;
% if solid rotor, must add that part too!
if sirb==0,
  zsf = 1/(1/zag + 1/z2c);
else
  z2s = j*x2rs + r2rs/s;
  zsf = 1/(1/zag + 1/z2c + 1/z2s);
end

% Belt Harmonic Sections
% Rotor Leakage Reactance
% This consists of slot, skew and zigzag terms 
x2a5 = xr5a + xk5 + xrz5a;
x2a7 = xr7a + xk7 + xrz7a;

% magnetizing element 
zag5 = j*xa5;
zag7 = j*xa7;

% cage part of rotor:
z2c5 = j*x2a5 + r2a5/s5;
z2c7 = j*x2a7 + r2a7/s7;

% if solid rotor, must add that part too!
if sirb==0,
  zs5 = 1/(1/zag5 + 1/z2c5);
  zs7 = 1/(1/zag7 + 1/z2c7);
else
  z2s5 = j*x2rs5 + r2rs5/s5;
  z2s7 = j*x2rs7 + r2rs7/s7;
  zs5 = 1/(1/zag5 + 1/z2c5 + 1/z2s5);
  zs7 = 1/(1/zag7 + 1/z2c7 + 1/z2s7);
end

%Zigzag harmonic sections, only if needed
if ma>1,
% Rotor Leakage Reactance
% This consists of slot, skew and zigzag terms 
  x2am = xrma + xkm + xrzma;
  x2ap = xrpa + xkp + xrzpa;

% magnetizing element 
  zagm = j*xam;
  zagp = j*xap;

% cage part of rotor:
  z2cm = j*x2am + r2am/sm;
  z2cp = j*x2ap + r2ap/sp;

% if solid rotor, must add that part too!
  if sirb==0,
    zsm = 1/(1/zagm + 1/z2cm);
    zsp = 1/(1/zagp + 1/z2cp);
  else
    z2sm = j*x2rsm + r2rsm/sm;
    z2sp = j*x2rsp + r2rsp/sp;
    zsm = 1/(1/zagm + 1/z2cm + 1/z2sm);
    zsp = 1/(1/zagp + 1/z2cp + 1/z2sp);
  end
end		% end of special section for zigzags

% here goes setting up for finding currents
% Total machine impedance
if ma == 1,
  zt = z1 + zsf + zs5 + zs7;
else
  zt = z1 + zsf + zs5 + zs7 + zsm + zsp;
end

% voltages across each section:
v1 = volt * z1/zt;
vf = volt * zsf/zt;
v5 = volt * zs5/zt;
v7 = volt * zs7/zt;
if ma>1,
  vm = volt * zsm/zt;
  vp = volt * zsp/zt;
end

% now we can compute currents in each important section  
ic = volt/zt;

i2c = vf/z2c;
i2c5 = v5/z2c5;
i2c7 = v7/z2c7;

if sirb > 0,
  i2s = vf/z2s;
  i2s5 = v5/z2s5;
  i2s7 = v7/z2s7;
end

if ma>1,
  i2cm = vm/z2cm;
  i2cp = vp/z2cp;
  if sirb > 0,
    i2sm = vm/z2sm;
    i2sp = vp/z2sp;
  end
end

% complex input power is volts times current
  pc = 3 * volt * conj(ic);
  watts = real(pc);

% Now we can compute electromagnetic power
pemf = 3*abs(i2c)^2 * r2a/s;
pem5c = 3*abs(i2c5)^2 * r2a5/s5;
pem7c = 3*abs(i2c7)^2 * r2a7/s7;
if ma == 1,
  if sirb == 0,
    pemfs = 0;
    pem5s = 0;
    pem7s = 0;
    pemmc = 0;
    pempc = 0;
    pemms = 0;
    pemps = 0;
  else
    pemfs = 3*abs(i2s)^2 * r2rs/s;
    pem5s = 3*abs(i2s5)^2 * r2rs5/s5;
    pem7s = 3*abs(i2s7)^2 * r2rs7/s7;
    pemmc = 0;
    pempc = 0;
    pemms = 0;
    pemps = 0;
  end
else
  if sirb == 0,
    pemfs = 0;
    pem5s = 0;
    pem7s = 0;
    pemmc = 3*abs(i2cm)^2 * r2am/sm;
    pempc = 3*abs(i2cp)^2 * r2ap/sp;
    pemms = 0;
    pemps = 0;
  else
    pemfs = 3*abs(i2s)^2 * r2rs/s;
    pem5s = 3*abs(i2s5)^2 * r2rs5/s5;
    pem7s = 3*abs(i2s7)^2 * r2rs7/s7;
    pemmc = 3*abs(i2cm)^2 * r2am/sm;
    pempc = 3*abs(i2cp)^2 * r2ap/sp;
    pemms = 3*abs(i2sm)^2 * r2rsm/sm;
    pemps = 3*abs(i2sp)^2 * r2rsp/sp;
  end
end

% Now estimate some losses, both included and excluded from the
% simple calculations

% Included are stator loss, core loss and rotor (slip) losses
Pa = 3*abs(ic)^2 * r1a;			%armature conduction
Pc = 3*abs(vf)^2 / rc;			%core loss
Pfc = 3*abs(i2c)^2 * r2a;		%fundamental rotor cage
P5c = 3*abs(i2c5)^2 * r2a5;		%fifth harmonic rotor cage
P7c = 3*abs(i2c7)^2 * r2a7;		%seventh harmonic rotor cage
if ma == 1,				%zigzag terms not needed
  if sirb == 0,				%rotor is laminated
  Pfs = 0;				%fundamental rotor body
  P5s = 0;				%fifth harmonic rotor body
  P7s = 0;				%seventh harmonic rotor body
  Pmc = 0;				%zigzag (lower) cage
  Pms = 0;				%zigzag (lower) body
  Ppc = 0;				%zigzag (upper) cage
  Pps = 0;				%zigzag (upper) body
  else					%rotor is solid (has conductivity)
  Pfs = 3*abs(i2s)^2 * r2rs;
  P5s = 3*abs(i2s5)^2 * r2rs5;
  P7s = 3*abs(i2s7)^2 * r2rs7;
  Pmc = 0;
  Pms = 0;
  Ppc = 0;
  Pps = 0;
  end
else					%zigzag terms are needed
  if sirb == 0,
  Pfs = 0;
  P5s = 0;
  P7s = 0;
  Pmc = 3*abs(i2cm)^2 * r2am;
  Ppc = 3*abs(i2cp)^2 * r2ap;
  Pms = 0;
  Pps = 0;
  else
  Pfs = 3*abs(i2s)^2 * r2rs;
  P5s = 3*abs(i2s5)^2 * r2rs5;
  P7s = 3*abs(i2s7)^2 * r2rs7;
  Pmc = 3*abs(i2cm)^2 * r2am;
  Ppc = 3*abs(i2cp)^2 * r2ap;
  Pms = 3*abs(i2sm)^2 * r2rsm;
  Pps = 3*abs(i2sp)^2 * r2rsp;
  end					%end of if sirb==0
end					%end of if ma == 1

% Calculation of stray no-load and load losses
% Not included (drag terms) are surface losses;
% These are no-load stray loss
Psurf = 3*abs(vf)^2 / rsurf;		% in laminations
if sirb > 0,
  Prsurf = 2*abs(vf)^2/ rsurfrs;	% in solid rotor body
else 
  Prsurf = 0;
end

% If the rotor is laminated (sirb == 0), we should estimate
% losses in the rotor teeth due to zigzag fluxes
% use only the highest frequency components
% this is a component of stray load loss
% harmonic conduction losses are the rest of stray load loss
if ma == 1,
  Bm = abs(5*p*v5/(2*l*r*na*ka5*omega));
  omfm = om5;
  Bp = abs(7*p*v7/(2*l*r*na*ka7*omega));
  omfp = omp;
else
  Bm = abs(nm*p*vm/(2*l*r*na*kam*omega));
  omfm = omm;
  Bp = abs(np*p*vp/(2*l*r*na*kap*omega));
  omfp = om7;
end

% Now estimate loss densities and total loss
% Pdt = mtoothr * pb * (abs(Bm/bb) ^ epps * abs(omfm/omb) ^ epf ...
%	     +abs(Bp/bb) ^ eps * abs(omfp/omb) ^epf);
Pdt = mtoothr * fepwr(Bm, omfm, pb, bb, omb, epps, epf) ...
	+ mtoothr * fepwr(Bp, omfp, pb, bb, omb, epps, epf);

% end of calculation of stray losses

% calculation of total electromagnetic power
  pconv = pemf + pem5c + pem7c + pemfs + pem5s + pem7s ...
      + pemmc + pemms + pempc + pemps;

% calculation of slip power
  pslip = Pfc + P5c + P7c + Pfs + P5s + P7s + Pmc + Pms + Ppc + Pps;

% Estimate of gap friction loss
% Reynold's Number in the gap
  ren = omegam*r*g/nuair;
% that gives a friction factor
  ff = .0076/ren^.25;
% and that in turn leads to windage loss
  pwind = 2*pi*r^4*omegam^3*l*rhoair*ff;

% fan pressure rise estimated from rotor peripheral speed
  deltap = .5* rhoair * (omegam * rfan)^2;
% Giving up on fan calculation for now (11/16/02)
% mass flow based on temperature rise
  loss = pwind + pslip + Pdt + Psurf + Prsurf + Pa + Pc;
  mdot = loss/(cpair * dtt);
% then fan power is volume flow times pressure drop
  pfan = mdot * deltap / (rhoair * etf);

% mechanical output power is electromagnetic minus windage minus
% electromagnetic (surface) drag

%  pmech = pconv - pslip - pwind - pfan - Psurf - Pdt - Prsurf;
  pmech = pconv - pslip - pwind - Psurf - Pdt - Prsurf;

% here is the power we need to convert:
%  Pcr = Prat + pslip + pwind + pfan + Psurf + Pdt + Prsurf;
  Pcr = Prat + pslip + pwind + Psurf + Pdt + Prsurf;

% and now we pick a new value for slip
  sold = s;
  cratio = Pcr/pconv;
  sgnu = sold * cratio;
  crit = abs(Prat/pmech-1);
  tol = 1e-6;
  if crit<tol, notdone=0; end
% This next is to show that the program really is thinking
  fprintf('.');
  s = sgnu;
end			% This is the end of the slip loop

vars = imag(pc);
va = abs(pc);
amps = abs(ic);
pfact = watts / va;                           % power factor
eff = pmech / watts;	                      % efficiency

% here is rotor speed in rpm
rpm = (30.0/pi) * omegam;
% developed air-gap shear stress
torqu = pconv/omegam;
gapa = 2 * pi * r * l;		              % air-gap area
shear = torqu / (r * gapa);                   %torque over area
Ja = na*amps/(p*ma*aslot);                    % armature slot cur density
hflux = (watts - pconv) / gapa;	              % heat flux at the gap
tipsp = r*omegam;			      % tip speed
fprintf('MOTOR Done: Ready\n');

