% Single Phase Induction Motor
% Power factor and efficiency vs. power
%
% Copyright 1997 James L. Kirtley Jr.
%
% Requires These Input Variables:
% Xm	Air-Gap Reactance (Ohms)
% X1	Armature Leakage
% X2	Rotor Leakage
% R2	Rotor Resistance
% R1	Armature Resistance
% p	Number of pole pairs
% f	Electrical Frequency (Hz)
% V	Terminal voltage (RMS)
% smax	maximum value of slip allowed
% Rc	Equivalent core resistance
 
ls = log(smax);
s = logspace(-3,ls);		% works best with log spacing in s

R2f = .5 * R2 ./ s;		% forward wave rotor resistance
R2r = .5 * R2 ./ (2 - s);	% reverse wave rotor resistance

Zf = par(j*Xm/2, j*X2/2 + R2f);	% impedance of forward going part
Zr = par(j*Xm/2, j*X2/2 + R2r);	% of reverse going part

Zt = Zf + Zr + j*X1 + R1;	% total impedance

It = V ./ Zt;			% interaction current

I2f = It .* cdiv(j*X2/2 + R2f, j*Xm/2);
I2r = It .* cdiv(j*X2/2 + R2r, j*Xm/2);

om = 2*pi*f;			% frequency, radians/sec
omm = (om/p) .* (1 - s);	% mechanical speed
rpm = (30/pi) .* omm;		% in RPM

Pin = V .* real(It) + V ^2/Rc;	% input power
Pm = (R2/2) .* abs(I2f) .^2 .* (1 - s) ./ s ...
     - (R2/2) .* abs(I2r) .^2 .* (1 - s) ./ (2 - s);
T = (p/om) * (R2/2) .* (abs(I2f) .^2 - abs(I2r) .^2 ./ (2 - s));

Iin = It + V/Rc;		% actual terminal current
eff = Pm ./ Pin;
pf = real(Iin) ./ abs(Iin);

plot(Pm, eff, Pm, pf);
xlabel('Output Power, Watts');
ylabel('Efficiency and Power Factor');
title('Single Phase Motor');
