% Single Phase Induction Motor
% Torque-Speed and Power-Speed Curve
%
% Copyright 1997 James L. Kirtley Jr.
%
% Requires These Input Variables:
% Xm	Air-Gap Reactance (Ohms)
% X1	Armature Leakage
% X2	Rotor Leakage
% R2	Rotor Resistance
% R1	Armature Resistance
% p	Number of pole pairs
% f	Electrical Frequency (Hz)
% V	Terminal voltage (RMS)

s = logspace(-3,0,200);		% works best with log spacing in s

%s = .01:.01:.2;			% to replicate some experiments we did
R2f = .5 * R2 ./ s;		% forward wave rotor resistance
R2r = .5 * R2 ./ (2 - s);	% reverse wave rotor resistance

Zf = par(j*Xm/2, j*X2/2 + R2f);	% impedance of forward going part
Zr = par(j*Xm/2, j*X2/2 + R2r);	% of reverse going part

Zt = Zf + Zr + j*X1 + R1;	% total impedance

It = V ./ Zt;			% terminal current

I2f = It .* cdiv(j*X2/2 + R2f, j*Xm/2);
I2r = It .* cdiv(j*X2/2 + R2r, j*Xm/2);

om = 2*pi*f;			% frequency, radians/sec
omm = (om/p) .* (1 - s);	% mechanical speed
rpm = (30/pi) .* omm;		% in RPM

Pin = V .* real(It);		% input power
Pm = (R2/2) .* abs(I2f) .^2 .* (1 - s) ./ s ...
     - (R2/2) .* abs(I2r) .^2 .* (1 - s) ./ (2 - s);
T = (p/om) * (R2/2) .* (abs(I2f) .^2 - abs(I2r) .^2 ./ (2 - s));

figure(1)
clf
plot(rpm, Pin, rpm, Pm);
title('Single Phase Motor');
xlabel('RPM');
ylabel('Input and Output Power, W');
figure(2)
plot(rpm, T)
title('Single Phase Motor');
xlabel('RPM');
ylabel('Torque, N-m');
