% Single Phase Induction Motor
% Torque-Speed and Power-Speed Curve
% Estimation of starting and running torque, etc.
% This is for a capacitor start motor
%
% Copyright 1997 James L. Kirtley Jr.
%
% Requires These Input Variables:
% Xm	Air-Gap Reactance (Ohms)
% X1	Armature Leakage
% X2	Rotor Leakage
% R2	Rotor Resistance
% R1	Armature Resistance
% Rb	Starting winding resistance
% Xb	Starting winding leakage
% alf	fundmental reactance factor
% p	Number of pole pairs
% f	Electrical Frequency (Hz)
% V	Terminal voltage (RMS)
% C	Starting capacitance (farads)

s = logspace(-3,0,200);		% works best with log spacing in s
ome = 2*pi*f;			% electrical frequency
oms = ome/p;			% synchronous speed
omm = oms .* (1-s);		% mechanical speed
rpm = (30/pi) .* omm;		% in RPM

	% part A: starting torque: capacitor in
% a number of parameters don't vary with speed
Za = j*(Xm+X1) + R1;		% main winding impedance
Zc = 1 / (j * ome * C);		% external capacitance
Zb = j*alf^2*Xm + j*Xb + Rb + Zc;
Zm1 = j*Xm/2;			% shorthand
Zm2 = alf*Xm/2;
b = [V V 0 0]';			% terminal voltage vector

Ia = zeros(size(s));		% some space for answers
Ib = zeros(size(s));
I2f = zeros(size(s));
I2r = zeros(size(s));

% now we have to run this over ranges of slip
for i = 1:length(s)

  Zf = (j*(Xm + X2) + R2/(s(i)))/2;
  Zr = (j*(Xm + X2) + R2/(2-s(i)))/2;

  A = [Za 0 Zm1 Zm1;0 Zb -Zm2 Zm2;Zm1 Zm2 Zf 0;Zm1 -Zm2 0 Zr];  

  x = A\b;			% x is the vector of currents

  Ia(i) = x(1);			% and here are our currents
  Ib(i) = x(2);
  I2f(i) = x(3);
  I2r(i) = x(4);
end				% rest of calc can be vectorized


It = Ia + Ib;			% terminal current


Pins = V .* real(It);		% input power
Pms = R2 .* abs(I2f) .^2 .* (1 - s) ./ s ...
     - R2 .* abs(I2r) .^2 .* (1 - s) ./ (2 - s);
Ts = (1/oms) * (R2/2) .* (abs(I2f) .^2 ./ s - abs(I2r) .^2 ./ (2 - s));
	
	% part B: running torque: capacitor out
R2f = .5*R2 ./ s;		% forward wave rotor resistance
R2r = .5*R2 ./ (2 - s);	% reverse wave rotor resistance

Zf = par(j*Xm/2, j*X2/2 + R2f);	% impedance of forward going part
Zr = par(j*Xm/2, j*X2/2 + R2r);	% of reverse going part

Zt = Zf + Zr + j*X1 + R1;	% total impedance

It = V ./ Zt;			% terminal current

I2f = It .* cdiv(j*X2/2 + R2f, j*Xm/2);
I2r = It .* cdiv(j*X2/2 + R2r, j*Xm/2);

Pin = V .* real(It);		% input power
Pm = (R2/2) .* abs(I2f) .^2 .* (1 - s) ./ s ...
     - (R2/2) .* abs(I2r) .^2 .* (1 - s) ./ (2 - s);
T = (1/oms) * (R2/2) .* (abs(I2f) .^2 ./s - abs(I2r) .^2 ./ (2 - s));

figure(1)
clf
plot(rpm, T, rpm, Ts, '--')
title('Single Phase Motor');
xlabel('RPM');
ylabel('Torque, N-m');
legend('Run', 'Start')
%legend('Running', 'Starting', 0)
