function [m,m2] = convind(t,y);
%  [m,m2] = convind(t,statev)
%
%  This script transforms the DQ stator and rotor fluxes computed using
%  ind.m and ode45 back into laboratory frame stator currents and voltages,
%  e.g., ias and vas for phase a. 
%
%  The variable w determines the reference frame in which the simulation
%  will be conducted.  With w = 377, the simulation variables will be in
%  a synchronously rotating reference frame.
%
%  On return, the output matrices m and m2 contain:
%	 m = [ids iqs idr iqr];
%	 m2 = [T ias ibs ics vas vbs vcs];
%  This script also plots the simulated rotor torque versus speed on return.
%
%  This software is distributed in the hope that it will be useful, but
%  WITHOUT ANY WARRANTY.  It is for educational use only.  Please do not
%  distribute or sell this software, or remove the copyright notice.  
%
%  Copyright, 1995, 1998, 2002  Steven B. Leeb
global P rs rr Xm X1s X1r we J Bl vds vqs vqr vdr Tl
% select reference frame (see ind.m)
 w = 377.; 

 Lm  = Xm/we;  % This is the magnetizing inductance
 L1s = X1s/we; % Stator leakage
 L1r = X1r/we; % Rotor leakage
 Las = L1s + Lm;
 Lar = L1r + Lm;

 lamqs = y(:,1);
 lamds = y(:,2);
 lamqr = y(:,3);
 lamdr = y(:,4);
 wr    = y(:,5); 
 th    = y(:,6);

 D = Lm*Lm - Las*Lar;
 idr   = (Lm*lamds - Las*lamdr)/D;
 iqr   = (Lm*lamqs - Las*lamqr)/D;
 iqs   = (Lm*lamqr - Lar*lamqs)/D;
 ids   = (Lm*lamdr - Lar*lamds)/D;

 T     = (3/2)*(P/2)*(lamqr.*idr - lamdr.*iqr);

 ias = cos(th).*ids - sin(th).*iqs;
 ibs = cos(th - 2.*pi/3.).*ids - sin(th - 2.*pi/3.).*iqs;
 ics = cos(th + 2.*pi/3.).*ids - sin(th + 2.*pi/3.).*iqs;
 vas = cos(th).*vds - sin(th).*vqs;
 vbs = cos(th - 2.*pi/3.).*vds - sin(th - 2.*pi/3.).*vqs;
 vcs = cos(th + 2.*pi/3.).*vds - sin(th + 2.*pi/3.).*vqs;


 m = [ids iqs idr iqr];
 m2 = [T ias ibs ics vas vbs vcs];
 figure(1)
 plot(2*3600*wr/(P*377),T);
 %pause


