function [slopes] = foc(t,statev)
%  [slopes] = foc(t,statev)
%
%  This script computes the behavior of a simple FOC for an 
%  induction machine with a current source drive.  For the first
%  0.6 seconds of the simulation, iqs is set to zero.  During this
%  time, the machine therefore produces no torque while the D-axis
%  rotor flux is experiencing a first order build-up.  
%
%  After the first 0.6 seconds, the D-axis rotor flux is approximately
%  constant and iqs is set to 1.0.  This produces a constant torque. 
%  The rotor experiences a linear increase in speed from zero, and
%  a parabolic increase in angle, because there is no load on the shaft.
%
%  Use this script with ODE45 to simulate the performance of the 
%  induction machine.
%  
%  Run indparam.m to load sample machine parameters before simulating.
%
%  This software is distributed in the hope that it will be useful, but
%  WITHOUT ANY WARRANTY.  It is for educational use only.  Please do not
%  distribute or sell this software, or remove the copyright notice.  
%
%  Copyright, 1995, 1998, 2002  Steven B. Leeb

global P rs rr Xm X1s X1r we J Bl vds vqs vqr vdr Tl
w = 377.;
Lm  = Xm/we;  % This is the magnetizing inductance
M   = Lm;
L1s = X1s/we; % Stator leakage
L1r = X1r/we; % Rotor leakage
Las = L1s + Lm;
Lar = L1r + Lm;
Tr = Lar/rr;

% Here are the stator drive currents.  Let ids build up lamdr before 
% we engage the drive.

ids = 10.0;

if t < 0.6 iqs = 0.0;
else iqs = 1.0;
end

% unpack the state variables

lamdr  = statev(1);
wr     = statev(2);  % wr = (P/2) * wm, where wm is actual shaft speed.
	             % wr is the rotor electrical speed.
thetam = statev(3);  % thetam is the rotor mechanical angle (position). 
th     = statev(4);  % Park's angle
lamqr  = statev(5);  % should be zero all the time.

% Here's the equation for iqr, from the flux linkages.
iqr   = (lamqr - M*iqs)/Lar;

% Compute the slip.  Don't compute slip if lamdr isn't built up yet.
if lamdr == 0 ws = 0;
else ws = iqs*M/(Tr*lamdr);
end

T = (3/2)*(P/2)*(M/Lar)*lamdr*iqs; % P=number of poles, *not* pole pairs


s1 = (M/Tr)*ids - lamdr/Tr;
s2 = (P/2)*(T - Tl)/J;
s3 = wr*2/P;
s4 = ws + wr;
s5 = -(rr*iqr + ws*lamdr);

slopes = [s1 s2 s3 s4 s5]';