function [slopes] = peind(t,statev)
%  [slopes] = peind(t,statev)
%
%  This script computes the state variable derivatives for a fifth
%  order model of a balanced, three phase AC induction machine.
%  The state variables are the D and Q stator and rotor fluxes, and
%  the rotor speed (wr).
%  Use this script with ODE45 to simulate the performance of the 
%  induction machine.
%  
%  Run indparam.m to load sample machine parameters before simulating.
%
%  *****  Simulates the stator voltage pattern made by a 6-pulse circuit  ****
%
%  This software is distributed in the hope that it will be useful, but
%  WITHOUT ANY WARRANTY.  It is for educational use only.  Please do not
%  distribute or sell this software, or remove the copyright notice.  
%
%  Copyright, 1995, 1998, 2002  Steven B. Leeb
%  The variable w determines the reference frame in which the simulation
%  will be conducted.  With w = 377, the simulation variables will be in
%  a synchronously rotating reference frame.
global P rs rr Xm X1s X1r we J Bl vds vqs vqr vdr Tl
w = 377.;
Lm  = Xm/we;  % This is the magnetizing inductance
L1s = X1s/we; % Stator leakage
L1r = X1r/we; % Rotor leakage
Las = L1s + Lm;
Lar = L1r + Lm;

lamqs = statev(1);
lamds = statev(2);
lamqr = statev(3);
lamdr = statev(4);
wr    = statev(5);
th    = statev(6);

vds = (2*180/pi)*(1 + (2/35)*cos(6*th) - (2/143)*cos(12*th));
vqs = -(2*180/pi)*((12/35)*sin(6*th) - (24/143)*sin(12*th));

D = Lm*Lm - Las*Lar;
idr   = (Lm*lamds - Las*lamdr)/D;
iqr   = (Lm*lamqs - Las*lamqr)/D;
iqs   = (Lm*lamqr - Lar*lamqs)/D;
ids   = (Lm*lamdr - Lar*lamds)/D;

s1 = (vqs - w*lamds - rs*iqs);
s2 = (vds + w*lamqs - rs*ids);
s3 = (vqr - (w - wr)*lamdr - rr*iqr);
s4 = (vdr + (w - wr)*lamqr - rr*idr);
% P is the number of poles, *not* pole pairs
T  = (3/2)*(P/2)*(lamqr*idr - lamdr*iqr);
s5 = (P/2)*(T - Tl)/J;
s6 = 377;
slopes = [s1 s2 s3 s4 s5 s6]';
