function[A, C] = attribut(D, DI, B, DEBUG)
% ****************************************************************** %
%                                                                    %
%         Permanent Magnet Motor-Generator, Stator in Slots          %
%             Internal (Flux Concentrating) Magnets                  %
%              Copyright 1997, James L. Kirtley Jr.                  %
%                                                                    %
% ****************************************************************** %
% attribut.m: adapted from pmbm.m: main design program
% for use with nda.m
% Copyright 1997  James L. Kirtley Jr.
% See 6.11s Copyright Notice for Rules of Use

% Requires the following input variables:

% Here are the fixed variables, defined in B[]
rpm = B(1);			    % Rotational Speed: Min Generating		
Preq = B(2);			% Required Generating Power
psi = B(3);			    % Power Factor for Generating
Treq = B(4);			% Required Motoring Torque
lama = B(5);			% slot fill fraction
Br = B(6);			    % magnet remanent flux density
siga = B(7);			% stator conductor conductivity
P0 = B(8);			    % Loss model iron base loss
B0 = B(9);			    % loss model base flux density
F0 = B(10);			    % loss model base frequency (Hz)
epb = B(11);			% loss model flux exponent
epf = B(12);			% loss model frequency exponen
Jmlim = B(13);			% limiting current density for motoring
Jglim = B(14);			% limiting current density for generating
Pmag = B(15);			% price of magnet material, $/kg
Pcu = B(16);			% price of copper conductor, $/kg
Pfe = B(17);			% price of iron, $/kg
Bsat = B(18);			% drop-dead level or iron flux density
rpm2 = B(19);			% speed for efficiency bogey
etamin = B(20);			% efficiency bogey
Preq2 = B(21);			% power at efficiency bogey point
Ph = B(22);			    % price of hoop material	
Dmax = B(23);			% maximum outside diameter
Lmax = B(24);			% maximum overall length
Rmax = B(25);			% max permitted D/L ratio
Ploss = B(26);          % price of loss, dollars/watt

% Here are the continuous variables to search, defined in D[]
r = D(1);			% rotor radius
gr = D(2);			% air-gap
hm = D(3);			% magnet radial extent
wm = D(4);			% magnet azimuthal extent (thickness)
l = D(5);			% active length
lamt = D(6);			% peripheral tooth (stator) fraction
fsd = D(7);			% slot depth to radius ratio
hd = D(8);			% slot depression depth
wd = D(9);			% slot depression width
fbi = D(10);			% back iron thickness ratio

% Here are the discrete variables to search, defined in DI[]
p = DI(1);			% number of pole pairs
m = DI(2);			% slots per pole per phase
nsp = DI(3);			% slots short-pitched

% Here are a few constants

muzero=pi*4e-7;			% free-space permeability
rhoair = 1.1774;		% density of air
nuair = 1.56e-5;		% kinematic viscosity of air
rhos = 7462;			% mass density of magnetic steel
rhoc = 8960;			% mass density of copper
rhom = 7500;			% magnet mass density
rhoh = 2000;			% guess at density of banding material
sthoop = 1.4e9;			% guess at strength of banding material
tol = 1e-3;			    % convergence tolerance

% DEBUG determines how the program behaves
% DEBUG = 0 generates no external output: used for NDA
% DEBUG = 1 generates screen output
% DEBUG = 2 generates file output into file out_file.txt

% Electrical frequency
f = p*rpm/60;				% in Hz
f2 = p*rpm2/60;				% efficiency point
omm = 2*pi*rpm/60;			% mechanical rad/sec
om = 2*pi*f;				% in radians/second
omm2 = 2*pi*rpm2/60;	    % mechanical rad/sec
om2 = 2*pi*f2;				% in radians/second

% First, generate the rest of the geometry
rhoavg = rhos + ((rhom - rhos)/rhos) * ...
         2*p*wm*hm/(pi*(r^2-(r-hm)^2));	% average rotor density
	 % this is required retaining hoop thickness
th = (rhoavg/3)* omm^2 * (r^3 - (r-hm)^3)/sthoop;

g = gr+th;				% magnetic gap
rs = r+g;				% stator inner radius
ns = 6*m*p;				% Number of stator slots
wt = 2*pi*(r+g+hd)*lamt/ns;		% tooth width
hs = fsd*r;				% slot depth
wst = 2*pi*(r+g+hd)*(1-lamt)/ns;	% slot top width
wsb = wst*(r+g+hd+hs)/(r+g+hd);		% slot bottom width
dc = fbi*r/p;				% core back iron depth
nsfp = ns/(2*p);			% full-pitched coil throw
nsct = nsfp - nsp;			% actual coil throw

% estimate of end cone length
thetae = acos(1-lamt);			% coil angle
laz = pi*(r+g+hd+.5*hs)*nsct/ns;	% azimuthal travel (half end)
le1 = laz/tan(thetae);			% end length (axial)
le2 = laz/sin(thetae);			% end length (half coil)

% rotor angles
tht = wm/r;				    % magnet included angle
thp = pi/p - tht;			% pole face angle


% Winding factor
gama = 2*pi*p/ns;			% electrical slot angle
kb = sin(m*gama/2)/(m*sin(gama/2));	% breadth factor
alfa = pi*nsct/nsfp;			% coil included angle
kp = sin(alfa/2);			% pitch angle
kw = kb * kp;				% winding factor

% Calculation of magnetic field
gamam = 1/(1+wm*thp*r/(4*g*hm));	% Magnet Permeance Modification Factor
% Fundamental Field
B1 = (4/pi)*sin(p*thp/2)*Br*(wm/(2*g))*gamam;

% Calculation of internal voltage
lambda = 2*rs*l*B1*kw/p;		% webers per turn

% Calculation of reactances: only two count here!
% Air-gap inductance: basic (Hy/turn^2)
Lag = (3/2)*(4/pi)*muzero*kw^2*l*rs/(p^2*(g+hm));
Lad = Lag*gamam*sin(p*thp/2);		% Direct-Axis Air-gap inductance
Laq = Lag*(1-sin(p*tht/2));		% Quadrature-Axis Air-gap inductance
% slot leakage
perm = muzero*l*(hd/wd+(1/3)*hs/wst);	% slot permeance
Lslot = 2*p*perm*(4*m-nsp)/((2*m*p)^2);	% per turn squared
% Synchronous Inductance (Hy/turn^2)
Ld = Lad + Lslot;			% direct-axis
Lq = Laq + Lslot;			% quadrature-axis

Xd = om*Ld;				% Synchronous Reactance (Ohms)
Xq = om*Lq;

% Misc. Lengths, Volumes and Weights
Lac = 2*(l+2*le2);			% Armature Conductor Length/turn
Aac = m*p*hs*.5*(wst+wsb)*lama;		% Armature Conductor Area * turns
Ma = 3*Lac*Aac*rhoc;			% Mass of Armature Conductor:
Lover = l+2*le1;			% Overall machine length
rci = r+g+hd+hs;			% Core Inside Radius
rco = rci + dc;				% Core Outside Radius
Dover = 2*rco;				% Overall Diameter

A = [0 0 0 0 0 0 0 0];  % this gets reset on return if machine is good

% check envelope
if Dover > Dmax			% too big!
  C=0;
  if DEBUG == 1
    fprintf('Diameter too large = %g\n',Dover);
  end
  return
end

if Lover > Lmax			% too big!
  C=0;
  if DEBUG == 1
    fprintf('Length too large = %g\n',Lover);
  end
  return
end

DoverL = Dover/Lover;

if DoverL > Rmax			% too flat!
  C=0;
  if DEBUG == 1
    fprintf('Diameter to Length too large = %g\n',DoverL);
  end
  return
end

% Core Mass
Mcb = rhos*l*pi*(rco^2-rci^2);			% Back Iron
Mct = rhos*l*(ns*wt*hs+2*pi*r*hd-ns*hd*wd);	% Teeth
Mfe = rhos*l*Dover^2;				% mass of punchings
Mc = Mcb + Mct;
Mm = 2*p*l*hm*wm*rhom;				% Magnet Mass
Mp = rhos*l*(pi*(r^2-(r-hm)^2)-2*p*hm*wm);	% Pole Piece Mass

Ra = Lac/(siga*Aac);				% stator resistance/turn^2

Bt = B1/(sqrt(2)*lamt);				% Tooth Flux Density (RMS)
Bb = B1*r/(sqrt(2)*p*dc);			% Back Iron Flux Density (RMS)
Pcb = Mcb*P0*abs(Bb/B0)^epb*abs(f2/F0)^epf;	% Core Back Loss
Pct = Mct*P0*abs(Bt/B0)^epb*abs(f2/F0)^epf;	% Teeth
Pc = Pcb+Pct;					% Iron Loss

% A couple of easy checks:
if Bt > Bsat,
  C = 0;
  if DEBUG==1, fprintf('Bt= %g\n',Bt); end
  return;
end
if Bb > Bsat
  C = 0;
  if DEBUG==1 fprintf('Bb= %g\n',Bb); end
  return;
end

% Now we see if this thing can do what we need
% First, check for motoring torque capability
NIm = sqrt(2) * Jmlim * Aac;		    % For motoring, find(peak)a-t
Ls = Lq - Ld;				            % saliency
tv = lambda/(4*Ls);			            % temporary variable
NId = tv - sqrt(tv^2 + (NIm/2)^2);	    % direct-axis ampere-turns
NIq = sqrt(NIm^2 - NId^2);		        % quadrature-axis ampere-turns
Te = 1.5*p*(lambda*NIq - Ls*NId*NIq);	% torque capability

if Te < Treq 
  C = 0; 
  if DEBUG==1, fprintf('Te= %g\n',Te); end
  return
end;					% first test

% idiot check number 1: motoring surface stress
taum = Te/(2*pi*r^2*l);

% Second, check if it can make generation
Ea = om*lambda/sqrt(2);			% RMS (!) Internal Voltage/turn

% we will need to iterate on the q-axis voltage e1
e1 = 1.1*Ea;				    % just a starting guess
not_done = 1;
Za = Ra + j*Xq;
Z = abs(Za);				    % internal impedance magnitude
psip = psi+pi/2-angle(Za);		% equivalent power factor angle
Xs = Xq - Xd;

kk = 1;
while not_done == 1
  kk = kk+1;
  xA = Z*Preq/(3*e1^2*cos(psi));		    % normalized internal impedance
  if (1-xA*sin(psip)/cos(psi))^2 < 4*xA^2,	% can't make generation
    C=0;
    if DEBUG==1
      fprintf('Generation Failed Test 1: xA = %g\n',xA);
    end
    return
  end
  tv = .5*(1-xA*sin(psip)/cos(psi));	% shorthand
  vr = sqrt(tv + sqrt(tv^2-xA^2));	    % voltage ratio
  NIg = Preq/(3*e1*vr);			        % required ampere-turns
  delta = atan(xA*cos(psip)/(1+xA*sin(psip)));
  NId = NIg * sin(psi+delta);		    % d- axis current
  nueaf = e1 - Xs*NId;			        % indicated Ea
  deltaeaf = nueaf - Ea;		        % next guess 
  if abs(deltaeaf) < tol,
    not_done = 0;
  end
  e1 = e1 - deltaeaf;			% correction
  if kk == 100,
    C = 0;
    return
    end
end
%end


Jg = NIg/Aac;				% required current density
if Jg > Jglim
   C=0;
   if DEBUG==1
      fprintf('Generation Failed Test 2: Jg = %g\n',Jg);
   end
   return
end

% idiot check number 2: generating surface stress
taug = (p/om)*Preq/(2*pi*r^2*l);

% Well, now, we have passed the preliminary tests:
% First, find current density for motoring

Jm = Jmlim*Treq/Te;			% initial guess
%  if DEBUG==1,
%    fprintf('Treq = %g Te = %g  Jmlim = %g Jm = %g\n',Treq,Te,Jmlim,Jm);
%  end

not_done = 1;
kk = 1;
while not_done == 1
  kk = kk+1;
  NIm = sqrt(2) * Jm * Aac;		% peak a-t
  tv = lambda/(4*Ls);			% temporary variable
  NId = tv - sqrt(tv^2 + (NIm/2)^2);	% direct-axis ampere-turns
  NIq = sqrt(NIm^2 - NId^2);		% quadrature-axis ampere-turns
  Te = 1.5*p*(lambda*NIq - Ls*NId*NIq);	% torque capability
  Jm = Jm * Treq/Te;
  if abs(1-Te/Treq) < tol not_done = 0; 
  end
  if kk == 100,
    C=0;
    return
  end
  
%  endif
%  endif
end					% should drop through with right Jm


% need to find an operating point, at frequency rpm2

Ea2 = om2*lambda/sqrt(2);			% RMS (!) Internal Voltage/turn

% we will need to iterate on the q-axis voltage e1
e12 = 1.1*Ea2;				% just a starting guess
not_done = 1;
Xd2 = om2*Ld;
Xq2 = om2*Lq;
Za2 = Ra + j*Xq2;
Z2 = abs(Za2);				% internal impedance magnitude
psip = psi+pi/2-angle(Za2);		% equivalent power factor angle
Xs2 = Xq2 - Xd2;

not_done = 1;
kk = 1;
while not_done == 1
  kk = kk+1;
  xA2 = Z2*Preq2/(3*e12^2*cos(psi));		% normalized internal impedance
  if (1-xA2*sin(psip)/cos(psi))^2 < 4*xA2^2	% can't make generation
    C=0;
    if DEBUG==1
      fprintf('Generation Failed Test 3: xA2 = %g\n',xA2);
    end
    return
  end
  tv = .5*(1-xA2*sin(psip)/cos(psi));	% shorthand
  vr = sqrt(tv + sqrt(tv^2-xA2^2));	% voltage ratio
  NIg2 = Preq/(3*e1*vr);			% required ampere-turns
  delta = atan(xA2*cos(psip)/(1+xA2*sin(psip)));
  NId2 = NIg2 * sin(psi+delta);		% d- axis current
  nueaf2 = e12 - Xs*NId2;		% indicated Ea
  deltaeaf2 = nueaf2 - Ea2;
  if abs(deltaeaf2) < tol
     not_done = 0;
  end
  e12 = e12 - deltaeaf2;			% indicated Ea
  if kk == 100
    C = 0;
    return
  end
%  endif
end


Jg2 = NIg2/Aac;				% required current density
if Jg2 > Jglim,
   C=0;
   if DEBUG==1
      fprintf('Generation Failed Test 4: Jg = %g\n',Jg);
   end
   return
end

% next is an efficiency calculation

Pa = 3*NIg2^2*Ra;			% Armature Conduction Losses
					% Estimate of gap friction loss
omegam = om2/p;				% rotational speed
ren = omegam*r*g/nuair;			% Reynold's Number in the gap
ff = .0076/ren^.25;			% that gives a friction factor
pwind = 2*pi*r^4*omegam^3*l*rhoair*ff;	% windage loss
Pin = Preq+Pc+Pa+pwind;			% input power
eff = Preq/Pin;				% efficiency

if eff < etamin			% missed the bogey
  C=0;
  if DEBUG==1, fprintf('eff= %g\n',eff); end
  return
end
% Mass of banding material
Mh = 2*pi*r*th*l*rhoh;

Costmat = Pmag*Mm  + Pcu*Ma + Pfe*Mfe + Ph*Mh;	% Materials Cost
Costm = Pmag*Mm;
Costc = Pcu*Ma;
Costi = Pfe*Mfe;
Costh = Ph*Mh;
Costl = (Pin-Preq)*Ploss;           % cost of losses
Cost = Costmat + Costl;

Mass = Mm + Ma + Mc + Mp + Mh;		% total weight

% rotational inertia constant
J = (pi/2) * rhos * l * r^4 + ...
    (rhom - rhos) * p * l * wm * (wm^2 * hm + 4 * (r^2 - (r-hm)^2))/6;

% Here is the vector of attributes
A = [1/Cost 1/Mass 1/Dover 1/Lover 1/J 1/Jm 1/Jg eff];

% and if we have made it this far,
C = 1;

if DEBUG==1,				% Screen Output
fprintf('PMBM: Buried Magnet Motor Analysis\n');
fprintf('Attributes:       Efficiency = %10.3f   Cost = %10.2f\n',eff,Cost);
fprintf('Mass = %10.3g    Dia = %10.3g    Length = %10.3g\n',Mass,Dover,Lover);
fprintf('Input Variables:\n');
fprintf('   r = %10.4g    g = %10.4g   hm = %10.4g   wm = %10.4g\n',r,g,hm,wm);
fprintf('   l = %10.4g lamt = %10.4g  fsd = %10.4d   hd = %10.4g\n',l,lamt,fsd,hd);
fprintf(' fbi = %10.4g    p = %10.0g    m = %10.0g  nsp = %10.0g\n',fbi,p,m,nsp);
fprintf('Details...\n');
fprintf('  B1 = %10.3g   Ea = %10.3g   Xd = %10.3g   Xq = %10.3g\n',B1,Ea,Xd,Xq);
fprintf('  Mc = %10.2g   Ma = %10.2g   Mp = %10.2g   Mm = %10.2g\n',Mc,Ma,Mp,Mm);
fprintf('  Mh = %10.3g   J  = %10.3g   Jm = %10.2g   Jg = %10.2g\n',Mh,J,Jm,Jg);
fprintf('  Bt = %10.2g   Bb = %10.2g   Te = %10.2g\n',Bt,Bb,Te);   
fprintf('  Pa = %10.2g   Pc = %10.2g pwind=%10.2g\n',Pa,Pc,pwind);
fprintf('taum = %10.2g taug = %10.2g\n',taum,taug);
fprintf('Cost of Materials = %10.2f  Cost of Losses = %10.2f\n', Costmat, Costl);
fprintf('Costm = %10.2f    Costc = %10.2f\n',Costm, Costc);
fprintf('Costi = %10.2f    Costh = %10.2f\n',Costi, Costh);
   
end					% End of DEBUG==1 block

if DEBUG==2,				% Saved output
fprintf('out_file.txt','PMBM: Buried Magnet Motor Analysis\n');
fprintf('out_file.txt','Attributes:       Efficiency = %10.3f   Cost = %10.2f\n',eff,Cost);
fprintf('out_file.txt','Mass = %10.3g    Dia = %10.3g    Length = %10.3g\n',Mass,Dover,Lover);
fprintf('out_file.txt','Input Variables:\n');
fprintf('out_file.txt','   r = %10.4g    g = %10.4g   hm = %10.4g   wm = %10.4g\n',r,g,hm,wm);
fprintf('out_file.txt','   l = %10.4g lamt = %10.4g  fsd = %10.4d   hd = %10.4g\n',l,lamt,fsd,hd);
fprintf('out_file.txt',' fbi = %10.4g    p = %10.0g    m = %10.0g  nsp = %10.0g\n',fbi,p,m,nsp);
fprintf('out_file.txt','Details...\n');
fprintf('out_file.txt','  B1 = %10.3g   Ea = %10.3g   Xd = %10.3g   Xq = %10.3g\n',B1,Ea,Xd,Xq);
fprintf('out_file.txt','  Mc = %10.2g   Ma = %10.2g   Mp = %10.2g   Mm = %10.2g\n',Mc,Ma,Mp,Mm);
fprintf('out_file.txt','  Mh = %10.3g   J  = %10.3g   Jm = %10.2g   Jg = %10.2g\n',Mh,J,Jm,Jg);
fprintf('out_file.txt','  Bt = %10.2g   Bb = %10.2g   Te = %10.2g\n',Bt,Bb,Te);   
fprintf('out_file.txt','  Pa = %10.2g   Pc = %10.2g pwind=%10.2g\n',Pa,Pc,pwind);
fprintf('out_file.txt','\n');
fprintf('out_file.txt','taum = %10.2g taug = %10.2g\n',taum,taug);
fprintf('out_file.txt','Costm = %10.2f    Costc = %10.2f\n',Costm, Costc);
fprintf('out_file.txt','Costi = %10.2f    Costh = %10.2f\n',Costi, Costh);
end					% End of DEBUG==2 block
